@@ -6,6 +6,7 @@ from gaia_sdk.graphql.request.type.Behaviour import Behaviour
 from gaia_sdk.graphql.request.type.Statement import Statement
 from gaia_sdk.graphql.request.type.Intent import Intent
 from gaia_sdk.graphql.request.type.Code import Code
+from gaia_sdk.graphql.request.type.Role import Role
 from gaia_sdk.graphql.request.type.SkillProvision import SkillProvision
 from gaia_sdk.graphql.request.type.Skill import Skill
 from gaia_sdk.graphql.request.type.Tenant import Tenant
@@ -18,6 +19,7 @@ from gaia_sdk.api.VariableRegistry import VariableRegistry
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 
 class Knowledge(list):
@@ -41,25 +43,6 @@ class Knowledge(list):
             return f'user(userId:{name1})' + '{' + entity.render(registry) + '}'
         self.append(callback)
 
-    def tenants(self, limit: int, offset: int, orderBy: OrderByField, order: Order, config: Callable[['Tenant'], None]):
-        def callback(registry: VariableRegistry):
-            name1 = registry.register("limit", limit)
-            name2 = registry.register("offset", offset)
-            name3 = registry.register("orderBy", orderBy)
-            name4 = registry.register("order", order)
-            entity = Tenant()
-            config(entity)
-            return f'tenants(limit:{name1}, offset:{name2}, orderBy:{name3}, order:{name4})' + '{' + entity.render(registry) + '}'
-        self.append(callback)
-
-    def tenant(self, tenantId: str, config: Callable[['Tenant'], None]):
-        def callback(registry: VariableRegistry):
-            name1 = registry.register("tenantId", tenantId)
-            entity = Tenant()
-            config(entity)
-            return f'tenant(tenantId:{name1})' + '{' + entity.render(registry) + '}'
-        self.append(callback)
-
     def api_keys(self, limit: int, offset: int, orderBy: OrderByField, order: Order, config: Callable[['ApiKey'], None]):
         def callback(registry: VariableRegistry):
             name1 = registry.register("limit", limit)
@@ -79,6 +62,46 @@ class Knowledge(list):
             return f'apiKey(apiKeyId:{name1})' + '{' + entity.render(registry) + '}'
         self.append(callback)
 
+    def roles(self, tenantId: str, limit: int, offset: int, orderBy: OrderByField, order: Order, config: Callable[['Role'], None]):
+        def callback(registry: VariableRegistry):
+            name1 = registry.register("tenantId", tenantId)
+            name2 = registry.register("limit", limit)
+            name3 = registry.register("offset", offset)
+            name4 = registry.register("orderBy", orderBy)
+            name5 = registry.register("order", order)
+            entity = Role()
+            config(entity)
+            return f'roles(tenantId:{name1}, limit:{name2}, offset:{name3}, orderBy:{name4}, order:{name5})' + '{' + entity.render(registry) + '}'
+        self.append(callback)
+
+    def role(self, tenantId: str, roleId: str, config: Callable[['Role'], None]):
+        def callback(registry: VariableRegistry):
+            name1 = registry.register("tenantId", tenantId)
+            name2 = registry.register("roleId", roleId)
+            entity = Role()
+            config(entity)
+            return f'role(tenantId:{name1}, roleId:{name2})' + '{' + entity.render(registry) + '}'
+        self.append(callback)
+
+    def tenants(self, limit: int, offset: int, orderBy: OrderByField, order: Order, config: Callable[['Tenant'], None]):
+        def callback(registry: VariableRegistry):
+            name1 = registry.register("limit", limit)
+            name2 = registry.register("offset", offset)
+            name3 = registry.register("orderBy", orderBy)
+            name4 = registry.register("order", order)
+            entity = Tenant()
+            config(entity)
+            return f'tenants(limit:{name1}, offset:{name2}, orderBy:{name3}, order:{name4})' + '{' + entity.render(registry) + '}'
+        self.append(callback)
+
+    def tenant(self, tenantId: str, config: Callable[['Tenant'], None]):
+        def callback(registry: VariableRegistry):
+            name1 = registry.register("tenantId", tenantId)
+            entity = Tenant()
+            config(entity)
+            return f'tenant(tenantId:{name1})' + '{' + entity.render(registry) + '}'
+        self.append(callback)
+
     def identities(self, limit: int, offset: int, orderBy: OrderByField, order: Order, config: Callable[['Identity'], None]):
         def callback(registry: VariableRegistry):
             name1 = registry.register("limit", limit)
@@ -236,13 +259,13 @@ class Knowledge(list):
             return f'edges(source:{name1}, limit:{name2}, offset:{name3}, orderBy:{name4}, order:{name5})' + '{' + entity.render(registry) + '}'
         self.append(callback)
 
-    def edge(self, source: str, target: str, config: Callable[['Edge'], None]):
+    def edge(self, source: str, edgeId: str, config: Callable[['Edge'], None]):
         def callback(registry: VariableRegistry):
             name1 = registry.register("source", source)
-            name2 = registry.register("target", target)
+            name2 = registry.register("edgeId", edgeId)
             entity = Edge()
             config(entity)
-            return f'edge(source:{name1}, target:{name2})' + '{' + entity.render(registry) + '}'
+            return f'edge(source:{name1}, edgeId:{name2})' + '{' + entity.render(registry) + '}'
         self.append(callback)
 
     def skills(self, tenantId: str, limit: int, offset: int, orderBy: OrderByField, order: Order, config: Callable[['Skill'], None]):
