@@ -3,11 +3,15 @@ from gaia_sdk.graphql.request.type.Prompt import Prompt
 
 from typing import Callable, List
 from gaia_sdk.api.VariableRegistry import VariableRegistry
+from gaia_sdk.graphql.request.enumeration.Order import Order
+from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 
 class UpdatedPromptImpulse(list):
     """
-    Impulse which indicates the resulf of a update prompt impulse
+    Impulse which indicates the result of a update prompt impulse
     """
 
     def id(self):
