@@ -5,6 +5,7 @@ from gaia_sdk.api.VariableRegistry import VariableRegistry
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 
 class User(list):
@@ -24,6 +25,24 @@ class User(list):
     def username(self):
         self.append(lambda x: "username")
 
+    """
+    The email of the user
+    """
+    def email(self):
+        self.append(lambda x: "email")
+
+    """
+    The first name of the user
+    """
+    def first_name(self):
+        self.append(lambda x: "firstName")
+
+    """
+    The last name of the user
+    """
+    def last_name(self):
+        self.append(lambda x: "lastName")
+
     """
     Is the User using 2FA
     """
