@@ -1,21 +1,37 @@
 
 
-from dataclasses import dataclass
 from typing import List
 Uuid = str
 String = str
 ISO8601 = str
 Struct = dict
 Float = float
+Int = int
+Boolean = bool
 from gaia_sdk.graphql.request.enumeration.RuntimeState import RuntimeState
 from gaia_sdk.graphql.request.enumeration.SkillState import SkillState
+from gaia_sdk.graphql.request.enumeration.Order import Order
+from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
-@dataclass
 class Code:
     """
-    this type represents the code information
+    Represents code information
     """
     dictionary: dict
+
+    def __init__(self, dictionary: dict):
+        self.dictionary = dictionary
+
+    def __eq__(self, other):
+        if type(other) is type(self):
+            return self.dictionary == other.dictionary
+        return False
+
+    def __repr__(self):
+        return {'dictionary': self.dictionary}
+
     """
     The code id
     """
@@ -50,8 +66,8 @@ class Code:
     The list of labels of the code
     """
     @property
-    def labellist(self) -> List[String]:
-        return list(map(lambda x: String(x), self.dictionary.get("labellist")))
+    def label_list(self) -> List[String]:
+        return list(map(lambda x: String(x), self.dictionary.get("labelList")))
     """
     The type of the code
     """
