@@ -1,5 +1,5 @@
 
-from gaia_sdk.graphql.response.type.ApiKey import ApiKey
+from gaia_sdk.graphql.response.type.CreatedApiKey import CreatedApiKey
 
 from typing import List
 Uuid = str
@@ -14,6 +14,7 @@ from gaia_sdk.graphql.request.enumeration.SkillState import SkillState
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 class CreatedApiKeyImpulse:
     """
@@ -36,5 +37,5 @@ class CreatedApiKeyImpulse:
     def id(self) -> Uuid:
         return Uuid(self.dictionary.get("id"))
     @property
-    def data(self) -> ApiKey:
-        return ApiKey(self.dictionary.get("data"))
+    def data(self) -> CreatedApiKey:
+        return CreatedApiKey(self.dictionary.get("data"))
